@@ -1,6 +1,6 @@
 from xchainpy_util.asset import Asset
 from xchainpy_client.models.balance import Balance
-from xchainpy_util.chain import BNBCHAIN
+from xchainpy_util.chain import Chain
 
 class BinanceBalance(Balance):
 
@@ -9,5 +9,5 @@ class BinanceBalance(Balance):
         :param balance: binance balance object
         :type balance: a dict contains: free, frozen, locked, symbol
         """
-        asset = Asset(BNBCHAIN, balance['symbol'])
+        asset = Asset(Chain.Binance.value, balance['symbol'])
         super().__init__(asset, balance['free'])
\ No newline at end of file
